;;; DO NOT MODIFY THIS FILE
(if (featurep 'tramp-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "lisp/_pkg.el")

(package-provide 'tramp :version 1.02 :type 'regular)

;;;***

;;;### (autoloads (tramp-file-name-handler) "tramp" "lisp/tramp.el")

(defcustom tramp-file-name-regexp "\\`/\\[.*\\]" "*Regular expression matching file names handled by tramp.\nThis regexp should match tramp file names but no other file names.\n(When tramp.el is loaded, this regular expression is prepended to\n`file-name-handler-alist', and that is searched sequentially.  Thus,\nif the tramp entry appears rather early in the `file-name-handler-alist'\nand is a bit too general, then some files might be considered tramp\nfiles which are not really tramp files.\n\nPlease note that the entry in `file-name-handler-alist' is made when\nthis file (tramp.el) is loaded.  This means that this variable must be set\nbefore loading tramp.el.  Alternatively, `file-name-handler-alist' can be\nupdated after changing this variable.\n\nAlso see `tramp-file-name-structure' and `tramp-make-tramp-file-format'." :group 'tramp :type 'regexp)

(autoload 'tramp-file-name-handler "tramp" "\
Invoke tramp file name handler.
Falls back to normal file name handler if no tramp file name handler exists." nil nil)

(add-to-list 'file-name-handler-alist (cons tramp-file-name-regexp 'tramp-file-name-handler))

;;;***

(provide 'tramp-autoloads)
